#
# spec file for package moonjit
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define lua_suffix 5_1
%define lib_suffix 2
Name:           moonjit
Version:        2.2.0
Release:        bp153.1.26
Summary:        JIT compiler for Lua language
License:        MIT
URL:            https://github.com/moonjit/moonjit
Source0:        https://github.com/moonjit/moonjit/archive/%{version}.tar.gz
Source1:        baselibs.conf
# PATCH-FIX-UPSTREAM moonjit105-string_gsub.patch gh#moonjit/moonjit#105 mcepl@suse.com
# fix string_gsub
Patch0:         moonjit105-string_gsub.patch
BuildRequires:  pkgconfig
Conflicts:      luajit
Provides:       lua51-luajit
Provides:       luajit = %{version}
Obsoletes:      lua51-luajit

%description
A Just-In-Time Compiler for Lua language

%package -n libluajit-%{lua_suffix}-%{lib_suffix}
Summary:        Library for JIT Lua compiler

%description -n libluajit-%{lua_suffix}-%{lib_suffix}
Libraries to use JIT Lua compiler

%package devel
Summary:        Devel files for LuaJIT
Requires:       %{name} = %{version}
Requires:       libluajit-%{lua_suffix}-%{lib_suffix} = %{version}
Conflicts:      luajit-devel
Provides:       luajit-devel = %{version}

%description devel
Devel files for luajit package

%prep
%setup -q -n moonjit-%{version}
%autopatch -p1

# Fix variables
sed -i "s,PREFIX= %{_prefix}/local,PREFIX= %{_prefix}," Makefile

%build
export CFLAGS="%{optflags} -DLUAJIT_ENABLE_LUA52COMPAT"
make %{?_smp_mflags} \
	Q= \
	DYNAMIC_CC="cc -fPIC" \
	LDCONFIG="true" \
	TARGET_AR="ar rcus" \
	TARGET_STRIP=: \
	MULTILIB=%{_lib}

%install
make DESTDIR=%{buildroot} install \
	INSTALL_LIB="%{buildroot}/%{_libdir}" \
	DYNAMIC_CC="cc -fPIC" \
	LDCONFIG="true" \
	TARGET_AR="ar rcus" \
	TARGET_STRIP=: \
	MULTILIB=%{_lib}
# remove static lib, not needed
rm %{buildroot}/%{_libdir}/*.a

# Beta version make install does not do this
ln -sf moonjit-%{version} %{buildroot}/%{_bindir}/moonjit
ln -sf moonjit-%{version} %{buildroot}/%{_bindir}/luajit

%check
%ifarch %arm ppc ppc64 ppc64le
make %{?_smp_mflags} check || { echo -e "WARNING: ignore check error for\narm*: https://github.com/moonjit/moonjit/issues/9\nppc*: https://github.com/moonjit/moonjit/issues/40"; }
%else
make %{?_smp_mflags} check
%endif

%post -n libluajit-%{lua_suffix}-%{lib_suffix} -p /sbin/ldconfig
%postun -n libluajit-%{lua_suffix}-%{lib_suffix} -p /sbin/ldconfig

%files
%{_bindir}/luajit
%{_bindir}/moonjit
%{_bindir}/moonjit-%{version}
%{_mandir}/man1/luajit.1%{?ext_man}
%{_datadir}/moonjit-%{version}/

%files -n libluajit-%{lua_suffix}-%{lib_suffix}
%{_libdir}/libluajit-5.1.so.*

%files devel
%{_includedir}/moonjit-2.2/
%{_libdir}/libluajit-5.1.so
%{_libdir}/pkgconfig/luajit.pc

%changelog
* Mon Mar 30 2020 Matej Cepl <mcepl@suse.com>
- Add moonjit105-string_gsub.patch to fix gsub method, which breaks
  other packages (namely neovim).
* Thu Mar 12 2020 Tomáš Chvátal <tchvatal@suse.com>
- No need to namespace luajit with update-alternatives, we really
  want just one version of it to be provided to keep things
  simple
* Thu Mar 12 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.2.0:
  * The v2.2 release of moonjit brings many new features that bring the
    project closer to its aim of unifying LuaJIT forks and compatibility
    with Lua.
- Do not suffix the version anymore as we support all lua variants,
  removes the patch:
  * luajit-lua-versioned.patch
* Wed Dec 18 2019 Michel Normand <normand@linux.vnet.ibm.com>
- Ignore make check error for PowerPC until upstream solved issue
  https://github.com/moonjit/moonjit/issues/40
- do the same for %%arm rather than to disable all %%check.
* Mon Dec 16 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Disable %%check on %%arm until the following issue is fixed:
  https://github.com/moonjit/moonjit/issues/9
* Thu Dec 12 2019 Andreas Schwab <schwab@suse.de>
- Use %%_lib
* Mon Dec  9 2019 Tomáš Chvátal <tchvatal@suse.com>
- Obsolete/provide lua51-luajit as it was the old luajit name
* Fri Dec  6 2019 Tomáš Chvátal <tchvatal@suse.com>
- Fork of luajit with more active upstream
- Version 2.1.2 building on top of 2.1.0-beta3 with following goodies:
  * fix for CVE-2019-19391
  * Support for ppc64 ppc64le s390 s390x
- Still carry the patch luajit-lua-versioned.patch to mark it as
  compatible with lua 5.1, future 2.2 release should contain
  support for 5.2 and 5.3 release of LUA
